<?php

namespace Drupal\cforge\Plugin\EntityReferenceSelection;

use Drupal\Core\Entity\Attribute\EntityReferenceSelection;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Plugin\EntityReferenceSelection\UserSelection;


/**
 * Provides specific access control for the user entity type.
 */
#[EntityReferenceSelection(
  id: "default:masquerade",
  label: new TranslatableMarkup("Trader selection"),
  entity_types: ["user"],
  group: "cforge",
  weight: 1
)]
class MasqueradeSelection extends UserSelection {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS') {
    $query = parent::buildEntityQuery($match, $match_operator);
    $cur_user = \Drupal::currentUser();
    $user_has_roles = $cur_user->getRoles(TRUE);
    if (empty($user_has_roles['local admin']) and $cur_user->id() <> 1) {
      $excluded_roles[] = 'local admin';
    }
    if (empty($user_has_roles[RID_COMMITTEE]) and $cur_user->id() <> 1) {
      $excluded_roles[] = RID_COMMITTEE;
    }
    if (isset($excluded_roles)) {
      $query->condition('uid', $excluded_uids, 'NOT IN');
      $excluded_uids = $this->entityTypeManager->getStorage('user')
        ->getQuery()->accessCheck(TRUE)
        ->condition('roles', $excluded_roles, 'IN')
        ->execute();
    }
    return $query;
  }

}
